@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://www.imagemagick.org/script/license.php                           %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -100,7 +100,7 @@ static MagickBooleanType
 static Image *ReadCMYKImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
-  const void
+  const unsigned char
     *pixels;
 
   Image
@@ -170,7 +170,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
       quantum_type=CMYKAQuantum;
       image->matte=MagickTrue;
     }
-  pixels=(const void *) NULL;
+  pixels=(const unsigned char *) NULL;
   if (image_info->number_scenes != 0)
     while (image->scene < image_info->scene)
     {
@@ -181,8 +181,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
       length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
       for (y=0; y < (ssize_t) image->rows; y++)
       {
-        pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-          &count);
+        pixels=(const unsigned char *) ReadBlobStream(image,length,
+          GetQuantumPixels(quantum_info),&count);
         if (count != (ssize_t) length)
           break;
       }
@@ -216,22 +216,22 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         if (scene == 0)
           {
             length=GetQuantumExtent(canvas_image,quantum_info,quantum_type);
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-              &count);
+            pixels=(const unsigned char *) ReadBlobStream(image,length,
+              GetQuantumPixels(quantum_info),&count);
           }
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const IndexPacket
-            *restrict canvas_indexes;
+            *magick_restrict canvas_indexes;
 
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register IndexPacket
-            *restrict indexes;
+            *magick_restrict indexes;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -285,8 +285,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (status == MagickFalse)
                 break;
             }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         break;
       }
@@ -308,22 +308,22 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         if (scene == 0)
           {
             length=GetQuantumExtent(canvas_image,quantum_info,CyanQuantum);
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-              &count);
+            pixels=(const unsigned char *) ReadBlobStream(image,length,
+              GetQuantumPixels(quantum_info),&count);
           }
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const IndexPacket
-            *restrict canvas_indexes;
+            *magick_restrict canvas_indexes;
 
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register IndexPacket
-            *restrict indexes;
+            *magick_restrict indexes;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -396,8 +396,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 if (SyncAuthenticPixels(image,exception) == MagickFalse)
                   break;
               }
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-              &count);
+            pixels=(const unsigned char *) ReadBlobStream(image,length,
+              GetQuantumPixels(quantum_info),&count);
           }
           if (image->previous == (Image *) NULL)
             {
@@ -417,16 +417,16 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         if (scene == 0)
           {
             length=GetQuantumExtent(canvas_image,quantum_info,CyanQuantum);
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-              &count);
+            pixels=(const unsigned char *) ReadBlobStream(image,length,
+              GetQuantumPixels(quantum_info),&count);
           }
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -464,8 +464,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
             }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -476,10 +476,10 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -517,8 +517,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
            }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -529,10 +529,10 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -570,8 +570,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
             }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -582,16 +582,16 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const IndexPacket
-            *restrict canvas_indexes;
+            *magick_restrict canvas_indexes;
 
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register IndexPacket
-            *restrict indexes;
+            *magick_restrict indexes;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -632,8 +632,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
             }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -646,10 +646,10 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
             for (y=0; y < (ssize_t) image->extract_info.height; y++)
             {
               register const PixelPacket
-                *restrict p;
+                *magick_restrict p;
 
               register PixelPacket
-                *restrict q;
+                *magick_restrict q;
 
               register ssize_t
                 x;
@@ -688,8 +688,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                   if (SyncAuthenticPixels(image,exception) == MagickFalse)
                     break;
                 }
-              pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-                &count);
+              pixels=(const unsigned char *) ReadBlobStream(image,length,
+                GetQuantumPixels(quantum_info),&count);
             }
             if (image->previous == (Image *) NULL)
               {
@@ -726,7 +726,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
               &count);
             if (count != (ssize_t) length)
               {
@@ -735,15 +735,15 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
               }
           }
-        pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-          &count);
+        pixels=(const unsigned char *) ReadBlobStream(image,length,
+          GetQuantumPixels(quantum_info),&count);
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -781,8 +781,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
             }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -803,7 +803,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
               &count);
             if (count != (ssize_t) length)
               {
@@ -812,15 +812,15 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
               }
           }
-        pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-          &count);
+        pixels=(const unsigned char *) ReadBlobStream(image,length,
+          GetQuantumPixels(quantum_info),&count);
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -858,8 +858,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
            }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -880,7 +880,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
               &count);
             if (count != (ssize_t) length)
               {
@@ -889,15 +889,15 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
               }
           }
-        pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-          &count);
+        pixels=(const unsigned char *) ReadBlobStream(image,length,
+          GetQuantumPixels(quantum_info),&count);
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -935,8 +935,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
            }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -957,7 +957,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         for (i=0; i < (ssize_t) scene; i++)
           for (y=0; y < (ssize_t) image->extract_info.height; y++)
           {
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
+            (void) ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
               &count);
             if (count != (ssize_t) length)
               {
@@ -966,21 +966,21 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                 break;
               }
           }
-        pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-          &count);
+        pixels=(const unsigned char *) ReadBlobStream(image,length,
+          GetQuantumPixels(quantum_info),&count);
         for (y=0; y < (ssize_t) image->extract_info.height; y++)
         {
           register const IndexPacket
-            *restrict canvas_indexes;
+            *magick_restrict canvas_indexes;
 
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           register IndexPacket
-            *restrict indexes;
+            *magick_restrict indexes;
 
           register PixelPacket
-            *restrict q;
+            *magick_restrict q;
 
           register ssize_t
             x;
@@ -1021,8 +1021,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
               if (SyncAuthenticPixels(image,exception) == MagickFalse)
                 break;
            }
-          pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-            &count);
+          pixels=(const unsigned char *) ReadBlobStream(image,length,
+            GetQuantumPixels(quantum_info),&count);
         }
         if (image->previous == (Image *) NULL)
           {
@@ -1045,7 +1045,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
             for (i=0; i < (ssize_t) scene; i++)
               for (y=0; y < (ssize_t) image->extract_info.height; y++)
               {
-                pixels=ReadBlobStream(image,length,
+                (void) ReadBlobStream(image,length,
                   GetQuantumPixels(quantum_info),&count);
                 if (count != (ssize_t) length)
                   {
@@ -1054,15 +1054,15 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                     break;
                   }
               }
-            pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-              &count);
+            pixels=(const unsigned char *) ReadBlobStream(image,length,
+              GetQuantumPixels(quantum_info),&count);
             for (y=0; y < (ssize_t) image->extract_info.height; y++)
             {
               register const PixelPacket
-                *restrict p;
+                *magick_restrict p;
 
               register PixelPacket
-                *restrict q;
+                *magick_restrict q;
 
               register ssize_t
                 x;
@@ -1100,8 +1100,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                   if (SyncAuthenticPixels(image,exception) == MagickFalse)
                     break;
                }
-              pixels=ReadBlobStream(image,length,GetQuantumPixels(quantum_info),
-                &count);
+              pixels=(const unsigned char *) ReadBlobStream(image,length,
+                GetQuantumPixels(quantum_info),&count);
             }
             if (image->previous == (Image *) NULL)
               {
@@ -1327,7 +1327,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1355,7 +1355,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1406,7 +1406,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1426,7 +1426,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1446,7 +1446,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1466,7 +1466,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1488,7 +1488,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
             for (y=0; y < (ssize_t) image->rows; y++)
             {
               register const PixelPacket
-                *restrict p;
+                *magick_restrict p;
 
               p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
               if (p == (const PixelPacket *) NULL)
@@ -1530,7 +1530,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1556,7 +1556,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1582,7 +1582,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1608,7 +1608,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
-            *restrict p;
+            *magick_restrict p;
 
           p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
@@ -1636,7 +1636,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
             for (y=0; y < (ssize_t) image->rows; y++)
             {
               register const PixelPacket
-                *restrict p;
+                *magick_restrict p;
 
               p=GetVirtualPixels(image,0,y,image->columns,1,
                 &image->exception);
