@@ -695,7 +695,9 @@ static Image *ReadMATImageV4(const ImageInfo *image_info,Image *image,
     if (image_info->ping != MagickFalse)
       {
         Swap(image->columns,image->rows);
-        return(image);
+        if(HDR.imagf==1) ldblk *= 2;
+        SeekBlob(image, HDR.nCols*ldblk, SEEK_CUR);
+        goto skip_reading_current;
       }
     status=SetImageExtent(image,image->columns,image->rows);
     if (status == MagickFalse)
@@ -800,6 +802,7 @@ static Image *ReadMATImageV4(const ImageInfo *image_info,Image *image,
     /*
       Allocate next image structure.
     */
+skip_reading_current:
     AcquireNextImage(image_info,image);
     if (GetNextImageInList(image) == (Image *) NULL)
       {
@@ -970,7 +973,11 @@ MATLAB_KO:
     }
 #endif
 
-    if(MATLAB_HDR.DataType!=miMATRIX) continue;  /* skip another objects. */
+    if (MATLAB_HDR.DataType!=miMATRIX)
+      {
+        clone_info=DestroyImageInfo(clone_info);
+        continue;  /* skip another objects. */
+      }
 
     MATLAB_HDR.unknown1 = ReadBlobXXXLong(image2);
     MATLAB_HDR.unknown2 = ReadBlobXXXLong(image2);
@@ -1144,6 +1151,8 @@ RestoreMSCWarning
     status=SetImageExtent(image,image->columns,image->rows);
     if (status == MagickFalse)
       {
+        if ((image != image2) && (image2 != (Image *) NULL))
+          image2=DestroyImage(image2);
         InheritException(exception,&image->exception);
         return(DestroyImageList(image));
       }
@@ -1329,8 +1338,6 @@ done_reading:
   if (quantum_info != (QuantumInfo *) NULL)
     quantum_info=DestroyQuantumInfo(quantum_info);
 END_OF_READING:
-  if (clone_info)
-    clone_info=DestroyImageInfo(clone_info);
   CloseBlob(image);
 
 
@@ -1348,6 +1355,8 @@ END_OF_READING:
         Image *tmp=p;
         if ((p->rows == 0) || (p->columns == 0)) {
           p=p->previous;
+          if (tmp == image2)
+            image2=(Image *) NULL;
           DeleteImageFromList(&tmp);
         } else {
           image=p;
