@@ -6,7 +6,7 @@
 %                     PPPP    AAA   N   N   GGGG   OOO                        %
 %                     P   P  A   A  NN  N  G      O   O                       %
 %                     PPPP   AAAAA  N N N  G GGG  O   O                       %
-%                     P   M  A   A  N  NN  G   G  O   O                       %
+%                     P      A   A  N  NN  G   G  O   O                       %
 %                     P      A   A  N   N   GGGG   OOO                        %
 %                                                                             %
 %                                                                             %
@@ -17,13 +17,13 @@
 %                                 March 2012                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://www.imagemagick.org/script/license.php                           %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -135,6 +135,9 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
   PangoContext
     *context;
 
+  PangoFontDescription
+    *description;
+
   PangoFontMap
     *fontmap;
 
@@ -318,20 +321,14 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
       (draw_info->direction == RightToLeftDirection))
     align=(PangoAlignment) (PANGO_ALIGN_LEFT+PANGO_ALIGN_RIGHT-align);
   pango_layout_set_alignment(layout,align);
-  if (draw_info->font != (char *) NULL)
-    {
-      PangoFontDescription
-        *description;
-
-      /*
-        Set font.
-      */
-      description=pango_font_description_from_string(draw_info->font);
-      pango_font_description_set_size(description,(int) (PANGO_SCALE*
-        draw_info->pointsize+0.5));
-      pango_layout_set_font_description(layout,description);
-      pango_font_description_free(description);
-    }
+  if (draw_info->font == (char *) NULL)
+    description=pango_font_description_new();
+  else
+    description=pango_font_description_from_string(draw_info->font);
+  pango_font_description_set_size(description,(int) (PANGO_SCALE*
+    draw_info->pointsize+0.5));
+  pango_layout_set_font_description(layout,description);
+  pango_font_description_free(description);
   option=GetImageOption(image_info,"pango:markup");
   if ((option != (const char *) NULL) && (IsMagickTrue(option) == MagickFalse))
     pango_layout_set_text(layout,caption,-1);
@@ -375,11 +372,17 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
         (image->y_resolution == 0.0 ? 90.0 : image->y_resolution)+45.0)/90.0+
         0.5));
     }
+  status=SetImageExtent(image,image->columns,image->rows);
+  if (status == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Render markup.
   */
-  stride=(size_t) cairo_format_stride_for_width(CAIRO_FORMAT_ARGB32,
-    (int) image->columns);
+  stride=(size_t) cairo_format_stride_for_width(CAIRO_FORMAT_ARGB32,(int)
+    image->columns);
   pixel_info=AcquireVirtualMemory(image->rows,stride*sizeof(*pixels));
   if (pixel_info == (MemoryInfo *) NULL)
     {
@@ -395,6 +398,9 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
   cairo_paint(cairo_image);
   cairo_set_operator(cairo_image,CAIRO_OPERATOR_OVER);
   cairo_translate(cairo_image,page.x,page.y);
+  cairo_set_source_rgba(cairo_image,QuantumScale*draw_info->fill.red,
+    QuantumScale*draw_info->fill.green,QuantumScale*draw_info->fill.blue,
+    QuantumScale*(QuantumRange-draw_info->fill.opacity));
   pango_cairo_show_layout(cairo_image,layout);
   cairo_destroy(cairo_image);
   cairo_surface_destroy(surface);
