@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -136,6 +136,12 @@ typedef struct _OpenCLCacheInfo
 
   cl_uint
     event_count;
+
+  MagickSizeType
+    length;
+
+  PixelPacket
+    *pixels;
 } OpenCLCacheInfo;
 
 typedef struct _CacheInfo
@@ -299,7 +305,8 @@ extern MagickPrivate cl_mem
   GetAuthenticOpenCLBuffer(const Image *,ExceptionInfo *);
 
 extern MagickPrivate void
-  AddOpenCLEvent(const Image *,cl_event);
+  AddOpenCLEvent(const Image *,cl_event),
+  SyncAuthenticOpenCLBuffer(const Image *);
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
