@@ -17,13 +17,13 @@
 %                              May  1993                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://www.imagemagick.org/script/license.php                           %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -497,7 +497,7 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
   for (y=0; ((y < (ssize_t) image->rows) && (null_lines < 3)); )
   {
     register PixelPacket
-      *restrict q;
+      *magick_restrict q;
 
     register ssize_t
       x;
@@ -505,9 +505,7 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
     /*
       Initialize scanline to white.
     */
-    p=scanline;
-    for (x=0; x < (ssize_t) image->columns; x++)
-      *p++=(unsigned char) 0;
+    ResetMagickMemory(scanline,0,sizeof(*scanline)*image->columns);
     /*
       Decode Huffman encoded scanline.
     */
@@ -904,7 +902,7 @@ RestoreMSCWarning \
 %  The format of the LZWEncodeImage method is:
 %
 %      MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
-%        unsigned char *restrict pixels)
+%        unsigned char *magick_restrict pixels)
 %
 %  A description of each parameter follows:
 %
@@ -917,7 +915,7 @@ RestoreMSCWarning \
 %
 */
 MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
-  unsigned char *restrict pixels)
+  unsigned char *magick_restrict pixels)
 {
 #define LZWClr  256UL  /* Clear Table Marker */
 #define LZWEod  257UL  /* End of Data marker */
@@ -1067,7 +1065,7 @@ MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
 %  The format of the PackbitsEncodeImage method is:
 %
 %      MagickBooleanType PackbitsEncodeImage(Image *image,const size_t length,
-%        unsigned char *restrict pixels)
+%        unsigned char *magick_restrict pixels)
 %
 %  A description of each parameter follows:
 %
@@ -1080,7 +1078,7 @@ MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
 %
 */
 MagickExport MagickBooleanType PackbitsEncodeImage(Image *image,
-  const size_t length,unsigned char *restrict pixels)
+  const size_t length,unsigned char *magick_restrict pixels)
 {
   int
     count;
@@ -1203,7 +1201,7 @@ MagickExport MagickBooleanType PackbitsEncodeImage(Image *image,
 %  The format of the ZLIBEncodeImage method is:
 %
 %      MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
-%        unsigned char *restrict pixels)
+%        unsigned char *magick_restrict pixels)
 %
 %  A description of each parameter follows:
 %
@@ -1231,7 +1229,7 @@ static void RelinquishZIPMemory(voidpf context,voidpf memory)
 }
 
 MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
-  unsigned char *restrict pixels)
+  unsigned char *magick_restrict pixels)
 {
   int
     status;
