@@ -17,13 +17,13 @@
 %                              August 2007                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://www.imagemagick.org/script/license.php                           %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -127,8 +127,8 @@ static void MatrixSignalHandler(int status)
 #endif
 
 static inline MagickOffsetType WriteMatrixElements(
-  const MatrixInfo *restrict matrix_info,const MagickOffsetType offset,
-  const MagickSizeType length,const unsigned char *restrict buffer)
+  const MatrixInfo *magick_restrict matrix_info,const MagickOffsetType offset,
+  const MagickSizeType length,const unsigned char *magick_restrict buffer)
 {
   register MagickOffsetType
     i;
@@ -167,8 +167,8 @@ static inline MagickOffsetType WriteMatrixElements(
   return(i);
 }
 
-static MagickBooleanType SetMatrixExtent(MatrixInfo *restrict matrix_info,
-  MagickSizeType length)
+static MagickBooleanType SetMatrixExtent(
+  MatrixInfo *magick_restrict matrix_info,MagickSizeType length)
 {
   MagickOffsetType
     count,
@@ -662,8 +662,8 @@ static inline ssize_t EdgeY(const ssize_t y,const size_t rows)
 }
 
 static inline MagickOffsetType ReadMatrixElements(
-  const MatrixInfo *restrict matrix_info,const MagickOffsetType offset,
-  const MagickSizeType length,unsigned char *restrict buffer)
+  const MatrixInfo *magick_restrict matrix_info,const MagickOffsetType offset,
+  const MagickSizeType length,unsigned char *magick_restrict buffer)
 {
   register MagickOffsetType
     i;
