@@ -17,13 +17,13 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://www.imagemagick.org/script/license.php                           %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -82,6 +82,7 @@
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#include "magick/utility-private.h"
 
 #ifdef MAGICKCORE_CLPERFMARKER
 #include "CLPerfMarker.h"
@@ -185,7 +186,7 @@ double readAccelerateTimer(AccelerateTimer* timer) {
   return (double)timer->_clocks/(double)timer->_freq;
 };
 
-MagickPrivate void RecordProfileData(MagickCLEnv clEnv, ProfiledKernels kernel, cl_event event)
+MagickPrivate MagickBooleanType RecordProfileData(MagickCLEnv clEnv, ProfiledKernels kernel, cl_event event)
 {
 #if PROFILE_OCL_KERNELS
   cl_int status;
@@ -209,6 +210,9 @@ MagickPrivate void RecordProfileData(MagickCLEnv clEnv, ProfiledKernels kernel,
     profileRecords[kernel].count += 1;
     UnlockSemaphoreInfo(clEnv->commandQueuesLock);
   }
+  return(MagickTrue);
+#else
+  return(MagickFalse);
 #endif
 }
 
@@ -292,16 +296,6 @@ void *OsLibraryGetFunctionAddress(void *library, const char *functionName)
 #endif
 }
 
-// unload a library.
-void OsLibraryUnload(void *library)
-{
-#ifdef MAGICKCORE_WINDOWS_SUPPORT
-    FreeLibrary( (HMODULE)library);
-#else
-    dlclose(library);
-#endif
-}
-
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -318,7 +312,7 @@ void OsLibraryUnload(void *library)
 %
 */
 
-MagickExport MagickCLEnv AcquireMagickOpenCLEnv()
+MagickPrivate MagickCLEnv AcquireMagickOpenCLEnv()
 {
   MagickCLEnv clEnv;
   clEnv = (MagickCLEnv) AcquireMagickMemory(sizeof(struct _MagickCLEnv));
@@ -356,20 +350,24 @@ MagickExport MagickCLEnv AcquireMagickOpenCLEnv()
 %
 */
 
-MagickExport MagickBooleanType RelinquishMagickOpenCLEnv(MagickCLEnv clEnv)
+MagickPrivate MagickBooleanType RelinquishMagickOpenCLEnv(MagickCLEnv clEnv)
 {
   if (clEnv != (MagickCLEnv) NULL)
-  {
-    while (clEnv->commandQueuesPos >= 0)
     {
-      clEnv->library->clReleaseCommandQueue(
-        clEnv->commandQueues[clEnv->commandQueuesPos--]);
+      while (clEnv->commandQueuesPos >= 0)
+      {
+        clEnv->library->clReleaseCommandQueue(
+          clEnv->commandQueues[clEnv->commandQueuesPos--]);
+      }
+      if (clEnv->programs[0] != (cl_program) NULL)
+        (void) clEnv->library->clReleaseProgram(clEnv->programs[0]);
+      if (clEnv->context != (cl_context) NULL)
+        clEnv->library->clReleaseContext(clEnv->context);
+      DestroySemaphoreInfo(&clEnv->lock);
+      DestroySemaphoreInfo(&clEnv->commandQueuesLock);
+      RelinquishMagickMemory(clEnv);
+      return MagickTrue;
     }
-    DestroySemaphoreInfo(&clEnv->lock);
-    DestroySemaphoreInfo(&clEnv->commandQueuesLock);
-    RelinquishMagickMemory(clEnv);
-    return MagickTrue;
-  }
   return MagickFalse;
 }
 
@@ -404,6 +402,7 @@ static MagickBooleanType bindOpenCLFunctions(void* library)
   BIND(clGetDeviceInfo);
 
   BIND(clCreateContext);
+  BIND(clReleaseContext);
 
   BIND(clCreateBuffer);
   BIND(clReleaseMemObject);
@@ -411,6 +410,7 @@ static MagickBooleanType bindOpenCLFunctions(void* library)
   BIND(clCreateProgramWithSource);
   BIND(clCreateProgramWithBinary);
   BIND(clBuildProgram);
+  BIND(clReleaseProgram);
   BIND(clGetProgramInfo);
   BIND(clGetProgramBuildInfo);
 
@@ -418,6 +418,7 @@ static MagickBooleanType bindOpenCLFunctions(void* library)
   BIND(clReleaseKernel);
   BIND(clSetKernelArg);
 
+  BIND(clFlush);
   BIND(clFinish);
 
   BIND(clEnqueueNDRangeKernel);
@@ -429,6 +430,7 @@ static MagickBooleanType bindOpenCLFunctions(void* library)
   BIND(clReleaseCommandQueue);
 
   BIND(clGetEventProfilingInfo);
+  BIND(clGetEventInfo);
   BIND(clWaitForEvents);
   BIND(clReleaseEvent);
   BIND(clRetainEvent);
@@ -563,7 +565,7 @@ static void UnlockDefaultOpenCLEnv() {
 %    o clEnv: the new default OpenCL environment.
 %
 */
-MagickExport MagickCLEnv SetDefaultOpenCLEnv(MagickCLEnv clEnv)
+MagickPrivate MagickCLEnv SetDefaultOpenCLEnv(MagickCLEnv clEnv)
 {
   MagickCLEnv oldEnv;
   LockDefaultOpenCLEnv();
@@ -850,65 +852,79 @@ static char* getBinaryCLProgramName(MagickCLEnv clEnv, MagickOpenCLProgram prog,
   return name;
 }
 
-static MagickBooleanType saveBinaryCLProgram(MagickCLEnv clEnv, MagickOpenCLProgram prog, unsigned int signature, ExceptionInfo* exception)
+static void saveBinaryCLProgram(MagickCLEnv clEnv,MagickOpenCLProgram prog,
+  unsigned int signature,ExceptionInfo* exception)
 {
-  MagickBooleanType saveSuccessful;
-  cl_int clStatus;
-  size_t binaryProgramSize;
-  unsigned char* binaryProgram;
-  char* binaryFileName;
-  FILE* fileHandle;
+  char
+    *filename;
 
-#ifdef MAGICKCORE_CLPERFMARKER
-  clBeginPerfMarkerAMD(__FUNCTION__,"");
-#endif
+  cl_uint
+    num_devices,
+    status;
 
-  binaryProgram = NULL;
-  binaryFileName = NULL;
-  fileHandle = NULL;
-  saveSuccessful = MagickFalse;
+  size_t
+    i,
+    size,
+    *program_sizes;
 
-  clStatus = clEnv->library->clGetProgramInfo(clEnv->programs[prog], CL_PROGRAM_BINARY_SIZES, sizeof(size_t), &binaryProgramSize, NULL);
-  if (clStatus != CL_SUCCESS)
-  {
-    (void) ThrowMagickException(exception, GetMagickModule(), ModuleFatalError, "clGetProgramInfo failed.", "'%s'", ".");
-    goto cleanup;
-  }
+  filename=getBinaryCLProgramName(clEnv,prog,signature);
+  status=clEnv->library->clGetProgramInfo(clEnv->programs[prog],
+    CL_PROGRAM_NUM_DEVICES,sizeof(cl_uint),&num_devices,NULL);
+  if (status != CL_SUCCESS)
+    return;
+  size=num_devices*sizeof(*program_sizes);
+  program_sizes=(size_t*) AcquireMagickMemory(size);
+  if (program_sizes == (size_t*) NULL)
+    return;
+  status=clEnv->library->clGetProgramInfo(clEnv->programs[prog],
+    CL_PROGRAM_BINARY_SIZES,size,program_sizes,NULL);
+  if (status == CL_SUCCESS)
+    {
+      size_t
+        binary_program_size;
 
-  binaryProgram = (unsigned char*) AcquireMagickMemory(binaryProgramSize);
-  clStatus = clEnv->library->clGetProgramInfo(clEnv->programs[prog], CL_PROGRAM_BINARIES, sizeof(char*), &binaryProgram, NULL);
-  if (clStatus != CL_SUCCESS)
-  {
-    (void) ThrowMagickException(exception, GetMagickModule(), ModuleFatalError, "clGetProgramInfo failed.", "'%s'", ".");
-    goto cleanup;
-  }
+      unsigned char
+        **binary_program;
 
-  binaryFileName = getBinaryCLProgramName(clEnv, prog, signature);
-  fileHandle = fopen(binaryFileName, "wb");
-  if (fileHandle != NULL)
-  {
-    fwrite(binaryProgram, sizeof(char), binaryProgramSize, fileHandle);
-    saveSuccessful = MagickTrue;
-  }
-  else
-  {
-    (void) ThrowMagickException(exception, GetMagickModule(), DelegateWarning,
-      "Saving binary kernel failed.", "'%s'", ".");
-  }
+      binary_program_size=num_devices*sizeof(*binary_program);
+      binary_program=(unsigned char **) AcquireMagickMemory(
+        binary_program_size);
+      for (i = 0; i < num_devices; i++)
+        binary_program[i]=AcquireQuantumMemory(MagickMax(*(program_sizes+i),1),
+          sizeof(**binary_program));
+      status=clEnv->library->clGetProgramInfo(clEnv->programs[prog],
+        CL_PROGRAM_BINARIES,binary_program_size,binary_program,NULL);
+      if (status == CL_SUCCESS)
+        {
+          for (i = 0; i < num_devices; i++)
+          {
+            int
+              file;
 
-cleanup:
-  if (fileHandle != NULL)
-    fclose(fileHandle);
-  if (binaryProgram != NULL)
-    RelinquishMagickMemory(binaryProgram);
-  if (binaryFileName != NULL)
-    free(binaryFileName);
+            size_t
+              program_size;
 
-#ifdef MAGICKCORE_CLPERFMARKER
-  clEndPerfMarkerAMD();
-#endif
-
-  return saveSuccessful;
+            program_size=*(program_sizes+i);
+            if (program_size < 1)
+              continue;
+            file=open_utf8(filename,O_WRONLY | O_CREAT | O_BINARY,S_MODE);
+            if (file != -1)
+              {
+                write(file,binary_program[i],program_size);
+                file=close(file);
+              }
+            else
+              (void) ThrowMagickException(exception,GetMagickModule(),
+                DelegateWarning,"Saving kernel failed.","`%s'",filename);
+            break;
+          }
+        }
+      for (i = 0; i < num_devices; i++)
+        binary_program[i]=(unsigned char *) RelinquishMagickMemory(
+          binary_program[i]);
+      binary_program=(unsigned char **) RelinquishMagickMemory(binary_program);
+    }
+  program_sizes=(size_t *) RelinquishMagickMemory(program_sizes);
 }
 
 static MagickBooleanType loadBinaryCLProgram(MagickCLEnv clEnv, MagickOpenCLProgram prog, unsigned int signature)
@@ -1554,6 +1570,7 @@ MagickPrivate MagickBooleanType RelinquishOpenCLCommandQueue(MagickCLEnv clEnv,
     }
   else
     {
+      clEnv->library->clFlush(queue);
       clEnv->commandQueues[++clEnv->commandQueuesPos]=queue;
       status=MagickTrue;
     }
@@ -2348,10 +2365,10 @@ static ds_status AcceleratePerfEvaluator(ds_device *device,
 #define NUM_ITER  2
 #define ReturnStatus(status) \
 { \
-  if (clEnv!=NULL) \
-    RelinquishMagickOpenCLEnv(clEnv); \
-  if (oldClEnv!=NULL) \
-    defaultCLEnv = oldClEnv; \
+  if (oldClEnv != (MagickCLEnv) NULL) \
+    defaultCLEnv=oldClEnv; \
+  if (clEnv != (MagickCLEnv) NULL) \
+    (void) RelinquishMagickOpenCLEnv(clEnv); \
   return status; \
 }
 
@@ -2566,6 +2583,8 @@ static MagickBooleanType autoSelectDevice(MagickCLEnv clEnv, ExceptionInfo* exce
     goto cleanup;
   }
 
+  clEnv->library=OpenCLLib;
+
   status = initDSProfile(&profile, IMAGEMAGICK_PROFILE_VERSION);
   if (status!=DS_SUCCESS) {
     (void) ThrowMagickException(exception, GetMagickModule(), ModuleFatalError, "Error when initializing the profile", "'%s'", ".");
@@ -2810,153 +2829,6 @@ MagickBooleanType OpenCLThrowMagickException(ExceptionInfo *exception,
   return(status);
 }
 
-#else
-
-struct _MagickCLEnv {
-  MagickBooleanType OpenCLInitialized;  /* whether OpenCL environment is initialized. */
-};
-
-MagickExport MagickCLEnv AcquireMagickOpenCLEnv()
-{
-  return NULL;
-}
-
-MagickExport MagickBooleanType RelinquishMagickOpenCLEnv(
-  MagickCLEnv magick_unused(clEnv))
-{
-  magick_unreferenced(clEnv);
-
-  return MagickFalse;
-}
-
-/*
-* Return the OpenCL environment
-*/
-MagickExport MagickCLEnv GetDefaultOpenCLEnv()
-{
-  return (MagickCLEnv) NULL;
-}
-
-MagickExport MagickCLEnv SetDefaultOpenCLEnv(
-  MagickCLEnv magick_unused(clEnv))
-{
-  magick_unreferenced(clEnv);
-
-  return (MagickCLEnv) NULL;
-}
-
-MagickExport MagickBooleanType SetMagickOpenCLEnvParam(
-  MagickCLEnv magick_unused(clEnv),MagickOpenCLEnvParam magick_unused(param),
-  size_t magick_unused(dataSize),void *magick_unused(data),
-  ExceptionInfo *magick_unused(exception))
-{
-  magick_unreferenced(clEnv);
-  magick_unreferenced(param);
-  magick_unreferenced(dataSize);
-  magick_unreferenced(data);
-  magick_unreferenced(exception);
-
-  return MagickFalse;
-}
-
-MagickExport MagickBooleanType GetMagickOpenCLEnvParam(
-  MagickCLEnv magick_unused(clEnv),MagickOpenCLEnvParam magick_unused(param),
-  size_t magick_unused(dataSize),void *magick_unused(data),
-  ExceptionInfo *magick_unused(exception))
-{
-  magick_unreferenced(clEnv);
-  magick_unreferenced(param);
-  magick_unreferenced(dataSize);
-  magick_unreferenced(data);
-  magick_unreferenced(exception);
-
-  return MagickFalse;
-}
-
-MagickExport MagickBooleanType InitOpenCLEnv(MagickCLEnv magick_unused(clEnv),
-  ExceptionInfo *magick_unused(exception))
-{
-  magick_unreferenced(clEnv);
-  magick_unreferenced(exception);
-
-  return MagickFalse;
-}
-
-MagickPrivate cl_command_queue AcquireOpenCLCommandQueue(
-  MagickCLEnv magick_unused(clEnv))
-{
-  magick_unreferenced(clEnv);
-
-  return (cl_command_queue) NULL;
-}
-
-MagickExport MagickBooleanType RelinquishCommandQueue(
-  MagickCLEnv magick_unused(clEnv),cl_command_queue magick_unused(queue))
-{
-  magick_unreferenced(clEnv);
-  magick_unreferenced(queue);
-
-  return MagickFalse;
-}
-
-MagickPrivate cl_kernel AcquireOpenCLKernel(
-  MagickCLEnv magick_unused(clEnv),MagickOpenCLProgram magick_unused(program),
-  const char *magick_unused(kernelName))
-{
-  magick_unreferenced(clEnv);
-  magick_unreferenced(program);
-  magick_unreferenced(kernelName);
-
-  return (cl_kernel) NULL;
-}
-
-MagickPrivate MagickBooleanType RelinquishOpenCLKernel(
-  MagickCLEnv magick_unused(clEnv),cl_kernel magick_unused(kernel))
-{
-  magick_unreferenced(clEnv);
-  magick_unreferenced(kernel);
-
-  return MagickFalse;
-}
-
-MagickPrivate unsigned long GetOpenCLDeviceLocalMemorySize(
-  MagickCLEnv magick_unused(clEnv))
-{
-  magick_unreferenced(clEnv);
-
-  return 0;
-}
-
-MagickExport MagickBooleanType InitImageMagickOpenCL(
-  ImageMagickOpenCLMode magick_unused(mode),
-  void *magick_unused(userSelectedDevice),void *magick_unused(selectedDevice),
-  ExceptionInfo *magick_unused(exception))
-{
-  magick_unreferenced(mode);
-  magick_unreferenced(userSelectedDevice);
-  magick_unreferenced(selectedDevice);
-  magick_unreferenced(exception);
-  return MagickFalse;
-}
-
-
-MagickPrivate
-MagickBooleanType OpenCLThrowMagickException(ExceptionInfo *exception,
-  const char *module,const char *function,const size_t line,
-  const ExceptionType severity,const char *tag,const char *format,...)
-{
-  magick_unreferenced(exception);
-  magick_unreferenced(module);
-  magick_unreferenced(function);
-  magick_unreferenced(line);
-  magick_unreferenced(severity);
-  magick_unreferenced(tag);
-  magick_unreferenced(format);
-  return(MagickFalse);
-}
-
-#endif /* MAGICKCORE_OPENCL_SUPPORT */
-
 char* openclCachedFilesDirectory;
 SemaphoreInfo* openclCachedFilesDirectoryLock;
 
@@ -3126,7 +2998,6 @@ void OpenCLLog(const char* message) {
 
 MagickPrivate void OpenCLTerminus()
 {
-#if MAGICKCORE_OPENCL_SUPPORT
   DumpProfileData();
   if (openclCachedFilesDirectory != (char *) NULL)
     openclCachedFilesDirectory=DestroyString(openclCachedFilesDirectory);
@@ -3140,8 +3011,73 @@ MagickPrivate void OpenCLTerminus()
   if (defaultCLEnvLock != (SemaphoreInfo*) NULL)
     DestroySemaphoreInfo(&defaultCLEnvLock);
   if (OpenCLLib != (MagickLibrary *)NULL)
-    OpenCLLib=(MagickLibrary *)RelinquishMagickMemory(OpenCLLib);
+    {
+      if (OpenCLLib->base != (void *) NULL)
+        (void) lt_dlclose(OpenCLLib->base);
+      OpenCLLib=(MagickLibrary *)RelinquishMagickMemory(OpenCLLib);
+    }
   if (OpenCLLibLock != (SemaphoreInfo*)NULL)
     DestroySemaphoreInfo(&OpenCLLibLock);
-#endif
-}
\ No newline at end of file
+}
+
+#else
+
+struct _MagickCLEnv {
+  MagickBooleanType OpenCLInitialized;  /* whether OpenCL environment is initialized. */
+};
+
+/*
+* Return the OpenCL environment
+*/
+MagickExport MagickCLEnv GetDefaultOpenCLEnv()
+{
+  return (MagickCLEnv) NULL;
+}
+
+MagickExport MagickBooleanType SetMagickOpenCLEnvParam(
+  MagickCLEnv magick_unused(clEnv),MagickOpenCLEnvParam magick_unused(param),
+  size_t magick_unused(dataSize),void *magick_unused(data),
+  ExceptionInfo *magick_unused(exception))
+{
+  magick_unreferenced(clEnv);
+  magick_unreferenced(param);
+  magick_unreferenced(dataSize);
+  magick_unreferenced(data);
+  magick_unreferenced(exception);
+  return(MagickFalse);
+}
+
+MagickExport MagickBooleanType GetMagickOpenCLEnvParam(
+  MagickCLEnv magick_unused(clEnv),MagickOpenCLEnvParam magick_unused(param),
+  size_t magick_unused(dataSize),void *magick_unused(data),
+  ExceptionInfo *magick_unused(exception))
+{
+  magick_unreferenced(clEnv);
+  magick_unreferenced(param);
+  magick_unreferenced(dataSize);
+  magick_unreferenced(data);
+  magick_unreferenced(exception);
+  return(MagickFalse);
+}
+
+MagickExport MagickBooleanType InitOpenCLEnv(MagickCLEnv magick_unused(clEnv),
+  ExceptionInfo *magick_unused(exception))
+{
+  magick_unreferenced(clEnv);
+  magick_unreferenced(exception);
+  return(MagickFalse);
+}
+
+MagickExport MagickBooleanType InitImageMagickOpenCL(
+  ImageMagickOpenCLMode magick_unused(mode),
+  void *magick_unused(userSelectedDevice),void *magick_unused(selectedDevice),
+  ExceptionInfo *magick_unused(exception))
+{
+  magick_unreferenced(mode);
+  magick_unreferenced(userSelectedDevice);
+  magick_unreferenced(selectedDevice);
+  magick_unreferenced(exception);
+  return(MagickFalse);
+}
+
+#endif /* MAGICKCORE_OPENCL_SUPPORT */
