@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,15 +15,15 @@
 
   MagickCore graphic resample methods.
 */
-#ifndef _MAGICKCORE_RESAMPLE_H
-#define _MAGICKCORE_RESAMPLE_H
+#ifndef MAGICKCORE_RESAMPLE_H
+#define MAGICKCORE_RESAMPLE_H
+
+#include "magick/cache-view.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-#include "magick/cache-view.h"
-
 /*
   WARNING:  The order of this table must also match the order of a table
   located in AcquireResizeFilter() in "resize.c" otherwise the users filter
